# Release Notes
---

## [1.8.1](https://github.com/osl-incubator/makim/compare/1.8.0...1.8.1) (2023-05-21)


### Bug Fixes

* Fix the rendering flow of env, vars and args ([#41](https://github.com/osl-incubator/makim/issues/41)) ([3235d98](https://github.com/osl-incubator/makim/commit/3235d988e93860d4224ca368bd7d39ed55014125))

# [1.8.0](https://github.com/osl-incubator/makim/compare/1.7.1...1.8.0) (2023-05-19)


### Features

* by default, for Xonsh shell, stop the target process if any command line fails ([#19](https://github.com/osl-incubator/makim/issues/19)) ([8fa4c1d](https://github.com/osl-incubator/makim/commit/8fa4c1ddb19af2ef215509feff2dd4055ca47561))

## [1.7.1](https://github.com/osl-incubator/makim/compare/1.7.0...1.7.1) (2023-05-19)


### Bug Fixes

* Fix release workflow and broken dependencies ([#40](https://github.com/osl-incubator/makim/issues/40)) ([c77c6f9](https://github.com/osl-incubator/makim/commit/c77c6f96f4b550e8bafe6d877719bb137d40aa11)), closes [/github.com/ionrock/cachecontrol/issues/292#issuecomment-1536120527](https://github.com//github.com/ionrock/cachecontrol/issues/292/issues/issuecomment-1536120527)

# [1.7.0](https://github.com/osl-incubator/makim/compare/1.6.7...1.7.0) (2023-05-19)


### Features

* Increase coverage of the env and env-file options for global, group and target scope ([#39](https://github.com/osl-incubator/makim/issues/39)) ([2481221](https://github.com/osl-incubator/makim/commit/24812213cc91a25e9da1ae0afaebdef36bac896b))

## [1.6.7](https://github.com/osl-incubator/makim/compare/1.6.6...1.6.7) (2023-04-22)


### Bug Fixes

* Break bash target when any line fails ([#37](https://github.com/osl-incubator/makim/issues/37)) ([9dab0f4](https://github.com/osl-incubator/makim/commit/9dab0f497bb8f99051e924d8e0decf160f00972c))

## [1.6.6](https://github.com/osl-incubator/makim/compare/1.6.5...1.6.6) (2023-04-07)


### Bug Fixes

* Fix both --version usage and the required property for arguments ([#35](https://github.com/osl-incubator/makim/issues/35)) ([3bc20e1](https://github.com/osl-incubator/makim/commit/3bc20e1941774ad07ca34ecfe511e4a54f766a7b))

## [1.6.5](https://github.com/osl-incubator/makim/compare/1.6.4...1.6.5) (2023-04-05)


### Bug Fixes

* Fix nested commands ([#34](https://github.com/osl-incubator/makim/issues/34)) ([790d2ba](https://github.com/osl-incubator/makim/commit/790d2bad746b2462bb8a6795b48eb913502a775e))

## [1.6.4](https://github.com/osl-incubator/makim/compare/1.6.3...1.6.4) (2023-03-21)


### Bug Fixes

* **groups:** change groups to accept dict instead of list && improve help cmd ([#28](https://github.com/osl-incubator/makim/issues/28)) ([a6b1672](https://github.com/osl-incubator/makim/commit/a6b1672413656072442caa0cc9ec5c0e5eb4786f))

## [1.6.3](https://github.com/osl-incubator/makim/compare/1.6.2...1.6.3) (2023-03-11)


### Bug Fixes

* Fix conditional parameter when --verbose is not given ([#27](https://github.com/osl-incubator/makim/issues/27)) ([e715268](https://github.com/osl-incubator/makim/commit/e715268e918746e4e4b2d783979ef39bf375a3a7))

## [1.6.2](https://github.com/osl-incubator/makim/compare/1.6.1...1.6.2) (2023-03-08)


### Bug Fixes

* Fix the mechanism for killing child processes when CTRL+C is pressed ([#25](https://github.com/osl-incubator/makim/issues/25)) ([00a9aff](https://github.com/osl-incubator/makim/commit/00a9affd98eb3259700cba3ac9173e5b9dcc5840))

## [1.6.1](https://github.com/osl-incubator/makim/compare/1.6.0...1.6.1) (2023-03-08)


### Bug Fixes

* Fix IF statement and arguments used by dependencies ([#24](https://github.com/osl-incubator/makim/issues/24)) ([e03886e](https://github.com/osl-incubator/makim/commit/e03886ef0340e1233926946397b6dda0432541f6))

# [1.6.0](https://github.com/osl-incubator/makim/compare/1.5.0...1.6.0) (2023-02-26)


### Features

* Add support for user defined shell app ([#22](https://github.com/osl-incubator/makim/issues/22)) ([dd4a7db](https://github.com/osl-incubator/makim/commit/dd4a7dbab93e7a2ea44bbfb3f1e2ad9b65da9b29))

# [1.5.0](https://github.com/osl-incubator/makim/compare/1.4.0...1.5.0) (2023-02-08)


### Features

* Add required argument option ([#16](https://github.com/osl-incubator/makim/issues/16)) ([dc79486](https://github.com/osl-incubator/makim/commit/dc794861f1230608306337e9e07283d0c8c56dd0))

# [1.4.0](https://github.com/osl-incubator/makim/compare/1.3.0...1.4.0) (2023-02-07)


### Features

* Add support to dot env file in the top level in the makim file ([#15](https://github.com/osl-incubator/makim/issues/15)) ([ee07cdb](https://github.com/osl-incubator/makim/commit/ee07cdbef497cd0183be97524e1d12cc06e7b589))

# [1.3.0](https://github.com/osl-incubator/makim/compare/1.2.0...1.3.0) (2023-02-05)


### Features

* Add dependency argument ([#13](https://github.com/osl-incubator/makim/issues/13)) ([7f28c68](https://github.com/osl-incubator/makim/commit/7f28c6873a78aa608106fdf9559d303ab5469b74))

# [1.2.0](https://github.com/osl-incubator/makim/compare/1.1.1...1.2.0) (2023-02-03)


### Features

* Add initial support for arguments ([#11](https://github.com/osl-incubator/makim/issues/11)) ([4d105d0](https://github.com/osl-incubator/makim/commit/4d105d0b6b1488af298877f8c0e9390256c5b559))

## [1.1.1](https://github.com/osl-incubator/makim/compare/1.1.0...1.1.1) (2023-02-03)


### Bug Fixes

* Fix release workflow ([#10](https://github.com/osl-incubator/makim/issues/10)) ([39146bb](https://github.com/osl-incubator/makim/commit/39146bb3946661c9630b1ad2bceb7eae297fbad5))

# [1.1.0](https://github.com/osl-incubator/makim/compare/1.0.2...1.1.0) (2023-02-03)


### Features

* Add support for variables for the target group ([#9](https://github.com/osl-incubator/makim/issues/9)) ([e3aa389](https://github.com/osl-incubator/makim/commit/e3aa389a07b7f5677328420f1389e84ed71bc7b3))

## [1.0.2](https://github.com/osl-incubator/makim/compare/1.0.1...1.0.2) (2023-01-26)


### Bug Fixes

* Fix support for Python 3.7.1, 3.8, 3.9, 3.10 ([#7](https://github.com/osl-incubator/makim/issues/7)) ([418f3de](https://github.com/osl-incubator/makim/commit/418f3de6dc4e5f1b963b32da9736163ea78ce5f5))

## [1.0.1](https://github.com/osl-incubator/makim/compare/1.0.0...1.0.1) (2023-01-25)


### Bug Fixes

* Suppress the sh traceback message error ([#5](https://github.com/osl-incubator/makim/issues/5)) ([dc3f4ad](https://github.com/osl-incubator/makim/commit/dc3f4ad1a949cd72e628742107cf5bd368721b7e))
